@@ -7,7 +7,7 @@
 #' @inheritParams R_template
 #'
 #' @return returns a list of the final results
-#' @export
+#' @noRd
 #' @family Poisson Wrapper Functions
 #' @examples
 #' library(data.table)
@@ -52,10 +52,10 @@ RunPoissonRegression_Omnibus <- function(df, pyr0 = "pyr", event0 = "event", nam
   if (class(df)[[1]] != "data.table") {
     tryCatch(
       {
-        df <- setDT(df)
+        df <- setDT(df) # nocov
       },
-      error = function(e) {
-        df <- data.table(df)
+      error = function(e) { # nocov
+        df <- data.table(df) # nocov
       }
     )
   }
@@ -181,10 +181,10 @@ RunPoissonEventAssignment <- function(df, pyr0 = "pyr", event0 = "event", names
   if (class(df)[[1]] != "data.table") {
     tryCatch(
       {
-        df <- setDT(df)
+        df <- setDT(df) # nocov
       },
-      error = function(e) {
-        df <- data.table(df)
+      error = function(e) { # nocov
+        df <- data.table(df) # nocov
       }
     )
   }
@@ -221,19 +221,19 @@ RunPoissonEventAssignment <- function(df, pyr0 = "pyr", event0 = "event", names
             sep = " "
           ))
         }
-        df <- df[get(col) != 1, ]
-        df0 <- df0[get(col) != 1, ]
+        #        df <- df[get(col) != 1, ]
+        #        df0 <- df0[get(col) != 1, ]
       } else {
         val_cols <- c(val_cols, col)
       }
-      data.table::setkeyv(df0, c(pyr0, event0))
+      #      data.table::setkeyv(df0, c(pyr0, event0))
     }
   } else {
     df0 <- data.table::data.table("a" = c(0, 0))
     val <- list(cols = c("a"))
     val_cols <- c("a")
   }
-  data.table::setkeyv(df, c(pyr0, event0))
+  #  data.table::setkeyv(df, c(pyr0, event0))
   all_names <- unique(names)
   df <- Replace_Missing(df, all_names, 0.0, control$verbose)
   dfc <- match(names, all_names)
@@ -246,7 +246,9 @@ RunPoissonEventAssignment <- function(df, pyr0 = "pyr", event0 = "event", names
   }
   e <- Assigned_Event_Poisson_transition(
     as.matrix(df[, ce, with = FALSE]),
-    as.matrix(df0), term_n, tform,
+    as.matrix(df0[, val_cols,
+      with = FALSE
+    ]), term_n, tform,
     a_n, dfc, x_all, 0,
     modelform, control, keep_constant,
     term_tot, model_control
@@ -254,63 +256,6 @@ RunPoissonEventAssignment <- function(df, pyr0 = "pyr", event0 = "event", names
   return(e)
 }
 
-#' Predicts how many events are due to baseline vs excess at the confidence bounds of a single parameter
-#'
-#' \code{RunPoissonEventAssignment_bound} uses user provided data, the results of a poisson regression, and options to calculate background and excess events
-#'
-#' @noRd
-#' @inheritParams R_template
-#' @param check_num the parameter number to check at the bounds of, indexed from 1 using the order returned by Colossus
-#' @param z Z score to use for confidence interval
-#' @family Poisson Wrapper Functions
-#' @return returns a list of the final results
-#'
-RunPoissonEventAssignment_bound <- function(df, pyr0 = "pyr", event0 = "event", alternative_model = list(), keep_constant = c(0), modelform = "M", check_num = 1, z = 2, control = list(), strat_col = "null", model_control = list()) {
-  if (class(df)[[1]] != "data.table") {
-    tryCatch(
-      {
-        df <- setDT(df)
-      },
-      error = function(e) {
-        df <- data.table(df)
-      }
-    )
-  }
-  names <- alternative_model$Parameter_Lists$names
-  term_n <- alternative_model$Parameter_Lists$term_n
-  tform <- alternative_model$Parameter_Lists$tforms
-  a_n <- alternative_model$beta_0
-  stdev <- alternative_model$Standard_Deviation
-  e_mid <- RunPoissonEventAssignment(
-    df, pyr0, event0, names, term_n,
-    tform, keep_constant, a_n, modelform,
-    control, strat_col,
-    model_control
-  )
-  a_n <- alternative_model$beta_0
-  a_n[check_num] <- a_n[check_num] - z * stdev[check_num]
-  e_low <- RunPoissonEventAssignment(
-    df, pyr0, event0, names, term_n,
-    tform, keep_constant, a_n, modelform,
-    control, strat_col,
-    model_control
-  )
-  a_n <- alternative_model$beta_0
-  a_n[check_num] <- a_n[check_num] + z * stdev[check_num]
-  e_high <- RunPoissonEventAssignment(
-    df, pyr0, event0, names,
-    term_n, tform, keep_constant,
-    a_n, modelform,
-    control, strat_col,
-    model_control
-  )
-  bound_results <- list(
-    "lower_limit" = e_low, "midpoint" = e_mid,
-    "upper_limit" = e_high
-  )
-  return(bound_results)
-}
-
 #' Calculates poisson residuals
 #'
 #' \code{RunPoissonRegression_Residual} uses user provided data, time/event columns,
@@ -363,10 +308,10 @@ RunPoissonRegression_Residual <- function(df, pyr0 = "pyr", event0 = "event", na
   if (class(df)[[1]] != "data.table") {
     tryCatch(
       {
-        df <- setDT(df)
+        df <- setDT(df) # nocov
       },
-      error = function(e) {
-        df <- data.table(df)
+      error = function(e) { # nocov
+        df <- data.table(df) # nocov
       }
     )
   }
@@ -406,19 +351,19 @@ RunPoissonRegression_Residual <- function(df, pyr0 = "pyr", event0 = "event", na
             sep = " "
           ))
         }
-        df <- df[get(col) != 1, ]
-        df0 <- df0[get(col) != 1, ]
+        #        df <- df[get(col) != 1, ]
+        #        df0 <- df0[get(col) != 1, ]
       } else {
         val_cols <- c(val_cols, col)
       }
-      data.table::setkeyv(df0, c(pyr0, event0))
+      #      data.table::setkeyv(df0, c(pyr0, event0))
     }
   } else {
     df0 <- data.table::data.table("a" = c(0, 0))
     val <- list(cols = c("a"))
     val_cols <- c("a")
   }
-  data.table::setkeyv(df, c(pyr0, event0))
+  #  data.table::setkeyv(df, c(pyr0, event0))
   all_names <- unique(names)
   df <- Replace_Missing(df, all_names, 0.0, control$verbose)
   dfc <- match(names, all_names)
@@ -454,10 +399,10 @@ PoissonCurveSolver <- function(df, pyr0 = "pyr", event0 = "event", names = c("CO
   if (class(df)[[1]] != "data.table") {
     tryCatch(
       {
-        df <- setDT(df)
+        df <- setDT(df) # nocov
       },
-      error = function(e) {
-        df <- data.table(df)
+      error = function(e) { # nocov
+        df <- data.table(df) # nocov
       }
     )
   }
@@ -566,10 +511,10 @@ RunPoisRegression_Omnibus_Multidose <- function(df, pyr0 = "pyr", event0 = "even
   if (class(df)[[1]] != "data.table") {
     tryCatch(
       {
-        df <- setDT(df)
+        df <- setDT(df) # nocov
       },
-      error = function(e) {
-        df <- data.table(df)
+      error = function(e) { # nocov
+        df <- data.table(df) # nocov
       }
     )
   }
