@@ -12,10 +12,10 @@ get_form_joint <- function(formula_list, df) {
   if (class(df)[[1]] != "data.table") {
     tryCatch(
       {
-        df <- setDT(df)
+        df <- setDT(df) # nocov
       },
-      error = function(e) {
-        df <- data.table(df)
+      error = function(e) { # nocov
+        df <- data.table(df) # nocov
       }
     )
   }
@@ -232,6 +232,9 @@ get_form <- function(formula, df) {
     model <- coxmodel(tstart, tend, event, strata, weight, null, term_n, tform, names, modelform, gmix_term, gmix_theta, c(), c(), df, expres_calls)
   } else if (grepl("pois", surv_model_type)) {
     model <- poismodel(pyr, event, strata, term_n, tform, names, modelform, gmix_term, gmix_theta, c(), c(), df, expres_calls)
+    if (all(strata != "NONE")) {
+      Check_Strata_Model(term_n, tform, modelform, gmix_term, gmix_theta)
+    } # verifies that a stratified model can be used
   } else if ((grepl("casecon", surv_model_type)) || (grepl("case_con", surv_model_type))) {
     model <- caseconmodel(tstart, tend, event, strata, null, term_n, tform, names, modelform, gmix_term, gmix_theta, c(), c(), df, expres_calls)
   } else if ((grepl("logit", surv_model_type)) || (grepl("logistic", surv_model_type))) {
@@ -327,6 +330,7 @@ get_form_list <- function(surv_obj, model_obj, df) {
 #' @family Formula Interpretation
 get_form_surv <- function(surv_obj, df) {
   surv_obj <- gsub(" ", "", surv_obj)
+  surv_obj <- gsub("\"", "", surv_obj) # remove literal strings if needed
   surv_model_type <- "NONE"
   tstart <- "NONE"
   tend <- "NONE"
@@ -828,7 +832,6 @@ get_form_risk <- function(model_obj, df) {
                   for (j in entries) {
                     df[[comb]] <- df[[comb]] * df[[j]]
                   }
-
                   col_name <- c(col_name, comb)
                 }
               }
@@ -849,6 +852,11 @@ get_form_risk <- function(model_obj, df) {
             }
           } else {
             # it is a factor
+            factor_arg_list <- list()
+            factor_arg_list[[1]] <- element_col
+            repeat_list <- c(list("_exp_type" = "factor"), copy(factor_arg_list))
+            repeat_list[["levels"]] <- levels(df[[element_col]])
+            expres_calls[[length(expres_calls) + 1]] <- repeat_list
             val <- factorize(df, element_col)
             df <- val$df
             col_name <- val$cols
@@ -885,37 +893,110 @@ get_form_risk <- function(model_obj, df) {
         }
         for (col in col_name) {
           for (model_term in model_terms) {
-            names <- c(names, col)
+            if (grepl("_int", model_term)) {
+              # we want to create a second column, for the intercept, to be normalized differently
+              new_col <- paste(col, ":intercept", sep = "")
+              if (!(new_col %in% names(df))) {
+                df[, new_col] <- df[, col, with = FALSE]
+              }
+              names <- c(names, new_col)
+            } else {
+              names <- c(names, col)
+            }
             tform <- c(tform, model_term)
             term_n <- c(term_n, term_num)
           }
         }
       }
     } else if (model_type %in% modelform_acceptable) {
-      if (model_type %in% c("m", "me", "multiplicative", "multiplicative-excess")) {
+      if (model_type %in% c("m", "multiplicative")) {
         model_type <- "M"
+      } else if (model_type %in% c("me", "multiplicative-excess")) {
+        model_type <- "ME"
       } else if (model_type %in% c("a", "additive")) {
         model_type <- "A"
       } else if (model_type %in% c("pa", "product-additive")) {
         model_type <- "PA"
       } else if (model_type %in% c("pae", "product-additive-excess")) {
         model_type <- "PAE"
-      } else if (model_type %in% c("gmix", "geometric-mixture")) {
+      } else if (model_type %in% c("gm", "gmix", "geometric-mixture")) {
         model_type <- "GMIX"
         model_paras <- substr(right_model_terms[term_i], third_split + 1, nchar(right_model_terms[term_i]) - 1)
-        model_paras <- tolower(strsplit(model_paras, ",")[[1]])
-        gmix_theta <- as.numeric(model_paras[1])
-        gmix_term <- ifelse(model_paras[2:length(model_paras)] == "e", 1, 0)
+        model_paras <- gsub("\"", "", model_paras) # remove literal strings if needed
+        #
+        if (is.na(model_paras) || model_paras == "") {
+          # Nothing, just give the defaults
+          gmix_theta <- 0.5
+          gmix_term <- c()
+        } else {
+          # There is something, but what?
+          if (grepl(",", model_paras)) {
+            # Multiple items
+            model_paras <- tolower(strsplit(model_paras, ",")[[1]])
+            # we need to start by checking if the first thing is a number
+            if (all(vapply(model_paras[1], function(x) grepl("^[\\-]{0,1}[0-9]*\\.{0,1}[0-9]*$", x), logical(1))) || all(vapply(model_paras[1], function(x) grepl("^[\\-]{0,1}[0-9]+e[\\-]{0,1}[0-9]+$", x), logical(1)))) {
+              # Good, the first item is a number
+              gmix_theta <- as.numeric(model_paras[1])
+              para_else <- model_paras[2:length(model_paras)]
+              # Check if they are all valid
+              if (all(vapply(para_else, function(x) grepl(x, "er"), logical(1)))) {
+                gmix_term <- ifelse(para_else == "e", 1, 0)
+              } else {
+                # Remaining entry was wrong
+                stop("Error: Gmix term had an invalid option after the theta value. Please only use 'e/r'")
+              }
+            } else {
+              # wasn't a number
+              gmix_theta <- 0.5
+              para_else <- model_paras[1:length(model_paras)]
+              # Check if they are all valid
+              if (all(vapply(para_else, function(x) grepl(x, "er"), logical(1)))) {
+                gmix_term <- ifelse(para_else == "e", 1, 0)
+              } else {
+                # Remaining entry was wrong
+                stop("Error: Gmix term had an invalid option. Please only use a number or 'e/r'")
+              }
+            }
+          } else {
+            # Single Item
+            if (all(vapply(model_paras, function(x) grepl("^[\\-]{0,1}[0-9]*\\.{0,1}[0-9]*$", x), logical(1))) || all(vapply(model_paras, function(x) grepl("^[\\-]{0,1}[0-9]+e[\\-]{0,1}[0-9]+$", x), logical(1)))) {
+              # It is a number, make it the gmix_theta
+              gmix_theta <- as.numeric(model_paras)
+              gmix_term <- c()
+            } else {
+              # it is not a number, is it a 'e' or 'r'?
+              if (grepl(tolower(model_paras), "er")) {
+                # it is an option!
+                gmix_theta <- 0.5
+                gmix_term <- ifelse(tolower(model_paras) == "e", 1, 0)
+              } else {
+                # Doesn't match anything
+                stop("Error: Gmix term had an invalid option. Please only use a number or 'e/r'")
+              }
+            }
+          }
+        }
+        #
       } else if (model_type %in% c("gmix-r", "relative-geometric-mixture")) {
         model_type <- "GMIX-R"
         model_paras <- substr(right_model_terms[term_i], third_split + 1, nchar(right_model_terms[term_i]) - 1)
-        model_paras <- tolower(strsplit(model_paras, ",")[[1]])
-        gmix_theta <- as.numeric(model_paras[1])
+        if (is.na(model_paras) || model_paras == "") {
+          # Nothing, just give the defaults
+          gmix_theta <- 0.5
+        } else {
+          model_paras <- tolower(strsplit(model_paras, ",")[[1]])
+          gmix_theta <- as.numeric(model_paras[1])
+        }
       } else if (model_type %in% c("gmix-e", "excess-geometric-mixture")) {
         model_type <- "GMIX-E"
         model_paras <- substr(right_model_terms[term_i], third_split + 1, nchar(right_model_terms[term_i]) - 1)
-        model_paras <- tolower(strsplit(model_paras, ",")[[1]])
-        gmix_theta <- as.numeric(model_paras[1])
+        if (is.na(model_paras) || model_paras == "") {
+          # Nothing, just give the defaults
+          gmix_theta <- 0.5
+        } else {
+          model_paras <- tolower(strsplit(model_paras, ",")[[1]])
+          gmix_theta <- as.numeric(model_paras[1])
+        }
       }
       if (modelform == "NONE") {
         modelform <- model_type
@@ -929,7 +1010,7 @@ get_form_risk <- function(model_obj, df) {
   if (!null) {
     term_tot <- max(term_n) + 1
     if (modelform == "NONE") {
-      modelform <- "M"
+      modelform <- "ME"
     } else if (modelform == "GMIX-R") {
       modelform <- "GMIX"
       gmix_term <- rep(0, term_tot)
@@ -937,6 +1018,11 @@ get_form_risk <- function(model_obj, df) {
       modelform <- "GMIX"
       gmix_term <- rep(1, term_tot)
     }
+    if (length(gmix_term) < term_tot) {
+      gmix_term <- c(gmix_term, rep(1.0, term_tot - length(gmix_term)))
+    } else if (length(gmix_term) > term_tot) {
+      stop("Error: The gmix option was used with more values than terms")
+    }
   }
   #
   if (length(tform) > 1) {
@@ -1262,20 +1348,20 @@ ColossusCoxStrataSurv <- function(...) {
   strata <- "NULL"
   # Is stata a named entry?
   if ("strata" %in% argName) {
-    strata <- args$strata
+    strata <- parse_literal_string(args$strata)
     res <- do.call(ColossusCoxSurv, args[names(args) != "strata"])
   } else if (all(argName == "")) {
-    strata <- args[[length(args)]]
+    strata <- parse_literal_string(args[[length(args)]])
     res <- do.call(ColossusCoxSurv, args[seq_len(length(args) - 1)])
   } else {
     if (argName[length(args)] == "") {
-      strata <- args[[length(args)]]
+      strata <- parse_literal_string(args[[length(args)]])
       res <- do.call(ColossusCoxSurv, args[seq_len(length(args) - 1)])
     } else {
       stop("Error: Final entry of Cox Strata object was not named correctly")
     }
   }
-  res["strata"] <- strata
+  res[["strata"]] <- strata
   res
 }
 
@@ -1575,13 +1661,13 @@ ColossusCaseConStrataSurv <- function(...) {
   #
   if ("event" %in% argName) {
     event <- args$event
-    strata <- args[names(args) != "event"][[1]]
+    strata <- parse_literal_string(args[names(args) != "event"][[1]])
   } else if ("strata" %in% argName) {
-    strata <- args$strata
+    strata <- parse_literal_string(args$strata)
     event <- args[names(args) != "strata"][[1]]
   } else {
     event <- args[[1]]
-    strata <- args[[2]]
+    strata <- parse_literal_string(args[[2]])
   }
   #
   list("event" = event, "strata" = strata)
@@ -1608,20 +1694,20 @@ ColossusCaseConTimeStrataSurv <- function(...) {
   strata <- "NULL"
   # Is stata a named entry?
   if ("strata" %in% argName) {
-    strata <- args$strata
+    strata <- parse_literal_string(args$strata)
     res <- do.call(ColossusCaseConTimeSurv, args[names(args) != "strata"])
   } else if (all(argName == "")) {
-    strata <- args[[length(args)]]
+    strata <- parse_literal_string(args[[length(args)]])
     res <- do.call(ColossusCaseConTimeSurv, args[seq_len(length(args) - 1)])
   } else {
     if (argName[length(args)] == "") {
-      strata <- args[[length(args)]]
+      strata <- parse_literal_string(args[[length(args)]])
       res <- do.call(ColossusCaseConTimeSurv, args[seq_len(length(args) - 1)])
     } else {
       stop("Error: Final entry of Case Control Strata and Time object was not named correctly")
     }
   }
-  res["strata"] <- strata
+  res[["strata"]] <- strata
   res
 }
 
