@@ -20,15 +20,8 @@ karno[93] <- 20
 df$karno <- karno
 df$trt <- df$trt - 1
 df$trt <- as.integer(df$trt == 0)
-cell_string <- df$celltype
-cell <- case_when(
-  cell_string == "squamous" ~ 1,
-  cell_string == "smallcell" ~ 2,
-  cell_string == "adeno" ~ 3,
-  cell_string == "large" ~ 0
-)
-df$cell <- cell
-
+cell_lvl <- c("large", "squamous", "smallcell", "adeno")
+df$cell <- as.integer(factor(df$celltype, level = cell_lvl)) - 1
 df$karno50 <- df$karno - 50
 
 df$trial <- 1
