@@ -267,11 +267,11 @@ List Plot_Omnibus_transition(IntegerVector term_n, StringVector tform, NumericVe
             _["log_bound"] = false,
             _["cox"] = true);
     //
-    bool Surv_bool      = model_control["surv"];
+    bool Surv_bool       = model_control["surv"];
     bool Schoenfeld_bool = model_control["schoenfeld"];
-    bool Risk_bool      = model_control["risk"];
-    bool Risk_Sub_bool  = model_control["risk_subset"];
-    int uniq_v          = model_control["unique_values"];
+    bool Risk_bool       = model_control["risk"];
+    bool Risk_Sub_bool   = model_control["risk_subset"];
+    int uniq_v           = model_control["unique_values"];
     //
     //  Performs regression
     List res;
@@ -1078,65 +1078,6 @@ void Write_Time_Dep(const NumericMatrix df0_Times, const NumericMatrix df0_dep,
     }
 }
 
-//' Generates factored columns in parallel
-//'
-//' \code{Gen_Fac_Par} Called directly from R, returns a matrix with factored columns
-//' @inheritParams CPP_template
-//'
-//' @return saves a dataframe to be used with time-dependent covariate analysis
-//' @noRd
-//'
-//  [[Rcpp::export]]
-NumericMatrix Gen_Fac_Par(const NumericMatrix df0, const NumericVector vals, const NumericVector cols, const int nthreads) {
-    const Map<MatrixXd> df(as<Map<MatrixXd> >(df0));
-    MatrixXd Mat_Fac = MatrixXd::Zero(df.rows(), vals.size());
-    //
-    #ifdef _OPENMP
-    #pragma omp parallel for schedule(dynamic) num_threads(nthreads)
-    #endif
-    for (int ijk = 0; ijk < vals.size(); ijk++) {
-        double col_c = cols[ijk];
-        double val_c = vals[ijk];
-        VectorXi select_ind_all = ((df.col(col_c).array() == val_c)).cast<int>();  //  indices at risk
-        //
-        //
-        int th = 1;
-        visit_lambda(select_ind_all,
-            [&Mat_Fac, ijk, th](double v, int i, int j) {
-                if (v == th)
-                    Mat_Fac(i, ijk) = 1;
-            });
-        //
-    }
-    //
-    return (wrap(Mat_Fac));
-}
-
-//' Interface between R code and the risk check
-//'
-//' \code{cox_ph_transition_single} Called directly from R, Defines the control variables and calls the function which only calculates the log-likelihood
-//' @inheritParams CPP_template
-//'
-//' @return LogLik_Cox_PH output : Log-likelihood of optimum, first derivative of log-likelihood, second derivative matrix, parameter list, standard deviation estimate, AIC, model information
-//' @noRd
-//'
-//  [[Rcpp::export]]
-bool risk_check_transition(IntegerVector term_n, StringVector tform, NumericVector a_n, IntegerVector dfc, MatrixXd df0, int fir, string modelform, List Control, List model_control, IntegerVector KeepConstant, int term_tot) {
-    int verbose = Control["verbose"];
-    //
-    int nthreads = Control["ncores"];
-    double gmix_theta = model_control["gmix_theta"];
-    IntegerVector gmix_term = model_control["gmix_term"];
-    Map<VectorXd> beta_0(as<Map<VectorXd> >(a_n));
-    //
-    //  Performs regression
-    //----------------------------------------------------------------------------------------------------------------//
-    bool res = Check_Risk(term_n, tform, beta_0, df0, dfc, fir, modelform, verbose, KeepConstant, term_tot, nthreads, gmix_theta, gmix_term);
-    //----------------------------------------------------------------------------------------------------------------//
-    return res;
-}
-
-
 //' Generates weightings for stratified poisson regression
 //'
 //' \code{Gen_Strat_Weight} Called from within c++, assigns vector of weights
@@ -1145,8 +1086,7 @@ bool risk_check_transition(IntegerVector term_n, StringVector tform, NumericVect
 //' @return assigns weight in place and returns nothing
 //' @noRd
 //'
-//
-void Gen_Strat_Weight(string modelform, const Ref<const MatrixXd>& dfs, const Ref<const MatrixXd>& PyrC, VectorXd& s_weights, const int nthreads, const StringVector& tform, const IntegerVector& term_n, const int& term_tot) {
+void Gen_Strat_Weight(string modelform, const Ref<const MatrixXd>& dfs, const Ref<const MatrixXd>& PyrC, VectorXd& s_weights, const int nthreads, const StringVector& tform, const IntegerVector& term_n, const int& term_tot, const double gmix_theta, const IntegerVector& gmix_term) {
     ArrayXd Pyrs  = dfs.transpose() * PyrC.col(0);
     ArrayXd Events = dfs.transpose() * PyrC.col(1);
     ArrayXd weight = Events.array() * Pyrs.array().pow(- 1).array();
@@ -1154,8 +1094,9 @@ void Gen_Strat_Weight(string modelform, const Ref<const MatrixXd>& dfs, const Re
     //
     s_weights = dfs * weight.matrix();
     //
-    vector<int> lin_count(term_tot, 0);
-    vector<int> dose_count(term_tot, 0);
+    vector<int> lin_count(term_tot, 0);  //  tracking which terms will go to 0 for only being linear
+    vector<int> dose_count(term_tot, 0);  // tracking which terms will be a sum of 1s, for being dose non-piecewise
+    vector<int> dose_lin_count(term_tot, 0);  // tracking which terms will go to 0 for being dose-piecewise
     for (int ij = 0; ij < (term_n.size()); ij++) {
         int tn = term_n[ij];
         if (as<string>(tform[ij]) == "loglin") {  //  setting parameters to zero makes the subterm 1
@@ -1168,16 +1109,20 @@ void Gen_Strat_Weight(string modelform, const Ref<const MatrixXd>& dfs, const Re
                 dose_count[tn] = dose_count[tn] + 1.0;
             } else if (tform[ij - 1] != "loglin_slope") {
                 dose_count[tn] = dose_count[tn] + 1.0;
-                //
             } else {}
         } else if (as<string>(tform[ij]) == "lin_slope") {  //  every other dose term sets the elements to 0
+            dose_lin_count[tn] = dose_lin_count[tn] + 1;
         } else if (as<string>(tform[ij]) == "lin_int") {
         } else if (as<string>(tform[ij]) == "quad_slope") {
+            dose_lin_count[tn] = dose_lin_count[tn] + 1;
         } else if (as<string>(tform[ij]) == "step_slope") {
+            dose_lin_count[tn] = dose_lin_count[tn] + 1;
         } else if (as<string>(tform[ij]) == "step_int") {
         } else if (as<string>(tform[ij]) == "lin_quad_slope") {
+            dose_lin_count[tn] = dose_lin_count[tn] + 1;
         } else if (as<string>(tform[ij]) == "lin_quad_int") {
         } else if (as<string>(tform[ij]) == "lin_exp_slope") {
+            dose_lin_count[tn] = dose_lin_count[tn] + 1;
         } else if (as<string>(tform[ij]) == "lin_exp_int") {
         } else if (as<string>(tform[ij]) == "lin_exp_exp_slope") {
         } else {
@@ -1187,10 +1132,13 @@ void Gen_Strat_Weight(string modelform, const Ref<const MatrixXd>& dfs, const Re
     //
     vector<double> term_val(term_tot, 0);
     for (int ijk = 0;  ijk < term_tot; ijk++) {
-        if (dose_count[ijk] == 0) {  //  If the dose term isn't used, then the default value is 1
-            dose_count[ijk] = 1.0;
+        if (dose_count[ijk] == 0) {  //  If the dose term isn't used
+            if (dose_lin_count[ijk] == 0) {  // If no dose terms that default to 0 are used
+                dose_count[ijk] = 1.0;  //  the default term value becomes 1
+            }
+            //  otherwise the default term value is 0
         }
-        if (lin_count[ijk] == 0) {  //  if the linear term isn't used, the entire term is 1 times the dose term value
+        if (lin_count[ijk] == 0) {  //  if the linear term isn't used, the entire term is 1 times the dose term value, accounting for the piecewise dose values
             term_val[ijk] = dose_count[ijk];
         } else {  //  if the linear term is used, the entire term is 0
             term_val[ijk] = 0;
@@ -1214,11 +1162,23 @@ void Gen_Strat_Weight(string modelform, const Ref<const MatrixXd>& dfs, const Re
     } else if (modelform == "M") {
         default_val = 1;
         for (int i = 1; i < term_tot; i++) {
-            default_val *= (1+term_val[i]);
+            default_val *= term_val[i];
         }
         default_val *= term_val[0];
-    } else if (modelform == "GM") {
-        throw invalid_argument("GM isn't implemented");
+    } else if (modelform == "ME") {
+        default_val = 1;
+        for (int i = 1; i < term_tot; i++) {
+            default_val *= (1 + term_val[i]);
+        }
+        default_val *= term_val[0];
+    } else if (modelform == "GMIX") {
+        double Ta = 1;
+        double Tm = 1;
+        for (int i = 1; i < term_tot; i++) {
+            Ta += (term_val[i] + gmix_term[i] - 1);
+            Tm *= (term_val[i] + gmix_term[i]);
+        }
+        default_val = term_val[0] * pow(Tm, gmix_theta) * pow(Ta, 1-gmix_theta);
     } else {
         throw invalid_argument("Model isn't implemented");
     }
