@@ -518,16 +518,6 @@ test_that("Missing Value verbose error", {
   expect_error(Replace_Missing(df, c("a", "b", "c", "d"), 0.0, -1))
 })
 
-# test_that( "Check Date Shift", {
-#     m0 <- c(1,1,2,2)
-#     m1 <- c(2,2,3,3)
-#     d0 <- c(1,2,3,4)
-#     d1 <- c(6,7,8,9)
-#     y0 <- c(1990,1991,1997,1998)
-#     y1 <- c(2001,2003,2005,2006)
-#     df <- data.table( "m0"=m0, "m1"=m1, "d0"=d0, "d1"=d1, "y0"=y0, "y1"=y1)
-#     expect_no_error(Date_Shift(df,c( "m0", "d0", "y0" ),c( "m1", "d1", "y1" ), "date_since" ))
-# })
 test_that("Check Date Shift, exact value", {
   m0 <- c(1, 1, 2, 2)
   m1 <- c(2, 2, 3, 3)
@@ -540,17 +530,6 @@ test_that("Check Date Shift, exact value", {
   expect_equal(as.numeric(e$date_since), c(4054, 4419, 2955, 2955))
 })
 
-# test_that( "Check Date Since", {
-#     m0 <- c(1,1,2,2)
-#     m1 <- c(2,2,3,3)
-#     d0 <- c(1,2,3,4)
-#     d1 <- c(6,7,8,9)
-#     y0 <- c(1990,1991,1997,1998)
-#     y1 <- c(2001,2003,2005,2006)
-#     df <- data.table( "m0"=m0, "m1"=m1, "d0"=d0, "d1"=d1, "y0"=y0, "y1"=y1)
-#     tref <- strptime( "3-22-1997", format = "%m-%d-%Y",tz = 'UTC' )
-#     expect_no_error(Time_Since(df,c( "m1", "d1", "y1" ),tref, "date_since" ))
-# })
 test_that("Check Date Since", {
   m0 <- c(1, 1, 2, 2)
   m1 <- c(2, 2, 3, 3)
@@ -574,3 +553,109 @@ test_that("Check Date Since, exact value", {
   e <- Time_Since(df, c("m1", "d1", "y1"), tref, "date_since")
   expect_equal(as.numeric(e$date_since), c(1417, 2148, 2908, 3274))
 })
+
+## ------------------------------------- ##
+## Checking the nested split and parse literal string codes
+## ------------------------------------- ##
+test_that("Usual nested split", {
+  temp_str <- "1,2,3,c(4, 5, 6)"
+  split_str <- nested_split(temp_str)
+  expect_equal(split_str, c("1", "2", "3", "c(4, 5, 6)"))
+  temp_str <- "1,2,3,c(4, 5, 6))"
+  split_str <- nested_split(temp_str)
+  expect_equal(split_str, c("1", "2", "3", "c(4, 5, 6))"))
+})
+test_that("Parse strings", {
+  temp_str <- "."
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, ".")
+  temp_str <- "e"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, "e")
+  temp_str <- "e0"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, "e0")
+  temp_str <- "1e"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, "1e")
+  #
+  temp_str <- "T"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, "T")
+  temp_str <- "t"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, "t")
+  #
+  temp_str <- "(1,2, 3,4)"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, "(1,2, 3,4)")
+})
+test_that("Parse number", {
+  temp_str <- "1"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, 1)
+  temp_str <- "1."
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, 1)
+  temp_str <- "-1"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, -1)
+  temp_str <- "0.1"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, 0.1)
+  temp_str <- ".1"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, 0.1)
+  temp_str <- "-.1"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, -0.1)
+  temp_str <- "1e-2"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, 0.01)
+  temp_str <- "1e2"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, 100)
+  temp_str <- "-1e-2"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, -0.01)
+  temp_str <- "1e0"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, 1)
+})
+test_that("Parse boolean", {
+  temp_str <- "true"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, TRUE)
+  temp_str <- "TRUE"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, TRUE)
+  temp_str <- "True"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, TRUE)
+  #
+  temp_str <- "false"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, FALSE)
+  temp_str <- "FALSE"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, FALSE)
+  temp_str <- "False"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, FALSE)
+})
+test_that("Parse vector", {
+  temp_str <- "c(1,2,3,4)"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, c(1, 2, 3, 4))
+})
+test_that("Parse list", {
+  temp_str <- "list(100)"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, list(100))
+  temp_str <- "list(x=100)"
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, list(x = 100))
+  temp_str <- 'list("x"=100)'
+  split_str <- parse_literal_string(temp_str)
+  expect_equal(split_str, list(x = 100))
+})
